library(testthat)
library(metalite.ae)

test_check("metalite.ae")
